aboutsummaryrefslogtreecommitdiff
path: root/engines/testbed/testbed.cpp
diff options
context:
space:
mode:
authorNeeraj Kumar2010-05-31 04:58:19 +0000
committerNeeraj Kumar2010-05-31 04:58:19 +0000
commita8a8ea31df50d8c6078cb95a949e84a58314d5b9 (patch)
treed020b7dbb511a4bb6ef26ffd08e6efe20fc2a77d /engines/testbed/testbed.cpp
parent3c629571b2212c3efca52e3fa8d742e368ba9352 (diff)
downloadscummvm-rg350-a8a8ea31df50d8c6078cb95a949e84a58314d5b9.tar.gz
scummvm-rg350-a8a8ea31df50d8c6078cb95a949e84a58314d5b9.tar.bz2
scummvm-rg350-a8a8ea31df50d8c6078cb95a949e84a58314d5b9.zip
the basic testbed skeleton, removed any trace of quux
svn-id: r49341
Diffstat (limited to 'engines/testbed/testbed.cpp')
-rw-r--r--engines/testbed/testbed.cpp51
1 files changed, 14 insertions, 37 deletions
diff --git a/engines/testbed/testbed.cpp b/engines/testbed/testbed.cpp
index 0d0e0c961c..f941f0dab4 100644
--- a/engines/testbed/testbed.cpp
+++ b/engines/testbed/testbed.cpp
@@ -1,19 +1,13 @@
#include "common/scummsys.h"
-
-#include "common/config-manager.h"
-#include "common/debug.h"
-#include "common/debug-channels.h"
-#include "common/EventRecorder.h"
-#include "common/file.h"
-#include "common/fs.h"
+#include "common/system.h"
#include "engines/util.h"
#include "testbed/testbed.h"
-namespace Quux {
+namespace Testbed {
-QuuxEngine::QuuxEngine(OSystem *syst)
+TestbedEngine::TestbedEngine(OSystem *syst)
: Engine(syst) {
// Put your engine in a sane state, but do nothing big yet;
// in particular, do not load data from files; rather, if you
@@ -22,28 +16,18 @@ QuuxEngine::QuuxEngine(OSystem *syst)
// Do not initialize graphics here
// However this is the place to specify all default directories
- const Common::FSNode gameDataDir(ConfMan.get("path"));
- SearchMan.addSubDirectoryMatching(gameDataDir, "sound");
-
- // Here is the right place to set up the engine specific debug levels
- DebugMan.addDebugChannel(kQuuxDebugExample, "example", "this is just an example for a engine specific debug level");
- DebugMan.addDebugChannel(kQuuxDebugExample2, "example2", "also an example");
- // Don't forget to register your random source
- g_eventRec.registerRandomSource(_rnd, "quux");
-
- printf("QuuxEngine::QuuxEngine\n");
+ printf("TestbedEngine::TestbedEngine()\n");
}
-QuuxEngine::~QuuxEngine() {
+TestbedEngine::~TestbedEngine() {
// Dispose your resources here
- printf("QuuxEngine::~QuuxEngine\n");
+ printf("TestbedEngine::~TestbedEngine()\n");
// Remove all of our debug levels here
- DebugMan.clearAllDebugChannels();
}
-
-Common::Error QuuxEngine::run() {
+
+Common::Error TestbedEngine::run() {
// Initialize graphics using following:
initGraphics(320, 200, false);
@@ -62,22 +46,15 @@ Common::Error QuuxEngine::run() {
//OSystem::kTransactionSizeChangeFailed here
//_system->endGFXTransaction();
- // Create debugger console. It requires GFX to be initialized
- _console = new Console(this);
-
// Additional setup.
- printf("QuuxEngine::init\n");
+ printf("TestbedEngine::init\n");
+
+ printf("Height: %d\n",_system->getHeight());
// Your main even loop should be (invoked from) here.
- printf("QuuxEngine::go: Hello, World!\n");
-
- // This test will show up if -d1 and --debugflags=example are specified on the commandline
- debugC(1, kQuuxDebugExample, "Example debug call");
-
- // This test will show up if --debugflags=example or --debugflags=example2 or both of them and -d3 are specified on the commandline
- debugC(3, kQuuxDebugExample | kQuuxDebugExample2, "Example debug call two");
-
+ printf("TestbedEngine::go: Hello, World!\n");
+
return Common::kNoError;
}
-} // End of namespace Quux
+} // End of namespace Testbed